==> aws-cdk-scala-msk_2.12-0.1.2-sources.jar: io/burkard/cdk/services/msk/CfnCluster.scala <==
package io.burkard.cdk.services.msk

@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object CfnCluster {

  def apply(
    internalResourceId: String,
    configurationInfo: Option[software.amazon.awscdk.services.msk.CfnCluster.ConfigurationInfoProperty] = None,
    kafkaVersion: Option[String] = None,
    tags: Option[AnyRef] = None,
    clientAuthentication: Option[software.amazon.awscdk.services.msk.CfnCluster.ClientAuthenticationProperty] = None,
    openMonitoring: Option[software.amazon.awscdk.services.msk.CfnCluster.OpenMonitoringProperty] = None,
    numberOfBrokerNodes: Option[Number] = None,
    encryptionInfo: Option[software.amazon.awscdk.services.msk.CfnCluster.EncryptionInfoProperty] = None,
    clusterName: Option[String] = None,
    loggingInfo: Option[software.amazon.awscdk.services.msk.CfnCluster.LoggingInfoProperty] = None,
    enhancedMonitoring: Option[String] = None,
    brokerNodeGroupInfo: Option[software.amazon.awscdk.services.msk.CfnCluster.BrokerNodeGroupInfoProperty] = None
  )(implicit stackCtx: software.amazon.awscdk.Stack): software.amazon.awscdk.services.msk.CfnCluster =
    software.amazon.awscdk.services.msk.CfnCluster.Builder
      .create(stackCtx, internalResourceId)
      .configurationInfo(configurationInfo.orNull)
      .kafkaVersion(kafkaVersion.orNull)
      .tags(tags.orNull)
      .clientAuthentication(clientAuthentication.orNull)
      .openMonitoring(openMonitoring.orNull)
      .numberOfBrokerNodes(numberOfBrokerNodes.orNull)
      .encryptionInfo(encryptionInfo.orNull)
      .clusterName(clusterName.orNull)
      .loggingInfo(loggingInfo.orNull)
      .enhancedMonitoring(enhancedMonitoring.orNull)
      .brokerNodeGroupInfo(brokerNodeGroupInfo.orNull)
      .build()
}

==> aws-cdk-scala-msk_2.12-0.2.0-sources.jar: io/burkard/cdk/services/msk/CfnCluster.scala <==
package io.burkard.cdk.services.msk

@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object CfnCluster {

  def apply(
    internalResourceId: String,
    kafkaVersion: String,
    numberOfBrokerNodes: Number,
    clusterName: String,
    brokerNodeGroupInfo: software.amazon.awscdk.services.msk.CfnCluster.BrokerNodeGroupInfoProperty,
    configurationInfo: Option[software.amazon.awscdk.services.msk.CfnCluster.ConfigurationInfoProperty] = None,
    tags: Option[AnyRef] = None,
    clientAuthentication: Option[software.amazon.awscdk.services.msk.CfnCluster.ClientAuthenticationProperty] = None,
    openMonitoring: Option[software.amazon.awscdk.services.msk.CfnCluster.OpenMonitoringProperty] = None,
    encryptionInfo: Option[software.amazon.awscdk.services.msk.CfnCluster.EncryptionInfoProperty] = None,
    loggingInfo: Option[software.amazon.awscdk.services.msk.CfnCluster.LoggingInfoProperty] = None,
    enhancedMonitoring: Option[String] = None
  )(implicit stackCtx: software.amazon.awscdk.Stack): software.amazon.awscdk.services.msk.CfnCluster =
    software.amazon.awscdk.services.msk.CfnCluster.Builder
      .create(stackCtx, internalResourceId)
      .kafkaVersion(kafkaVersion)
      .numberOfBrokerNodes(numberOfBrokerNodes)
      .clusterName(clusterName)
      .brokerNodeGroupInfo(brokerNodeGroupInfo)
      .configurationInfo(configurationInfo.orNull)
      .tags(tags.orNull)
      .clientAuthentication(clientAuthentication.orNull)
      .openMonitoring(openMonitoring.orNull)
      .encryptionInfo(encryptionInfo.orNull)
      .loggingInfo(loggingInfo.orNull)
      .enhancedMonitoring(enhancedMonitoring.orNull)
      .build()
}
